/*  Autopackage GTK+ frontend
 *  Copyright (C) 2003  Hongli Lai <h.lai@chello.nl>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef _PACKAGE_C_
#define _PACKAGE_C_

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include "package.h"


#define stripNewline(str) if (strlen (str) > 0 && str[strlen (str) - 1] == '\n') str[strlen (str) - 1] = 0


PackageInfo *
package_info_load (gchar *filename)
{
	FILE *f;
	gchar buf[1024];
	PackageInfo *info;

	g_return_val_if_fail (filename != NULL, NULL);
	if (!g_file_test (filename, G_FILE_TEST_EXISTS)) return NULL;

	f = fopen (filename, "r");
	if (!f) return NULL;

	/* Autopackages are bash scripts so check for interpreter line */
	if (!fgets (buf, sizeof (buf), f) || strcmp (buf, "#!/bin/bash\n") != 0)
	{
		fclose (f);
		return NULL;
	}

	info = (PackageInfo *) g_new0 (PackageInfo, 1);
	info->filename = g_strdup (filename);
	while (!feof (f) && fgets (buf, sizeof (buf), f)
	  && strcmp (buf, "## END OF STUB") != 0 && strcmp (buf, "## END OF STUB\n") != 0)
	{
		stripNewline (buf);

		if (strncmp (buf, "# SHORTNAME ", 12) == 0)
			info->shortName = g_strdup (buf + 12);
		else if (strncmp (buf, "# DISPLAYNAME  ", 14) == 0)
			info->displayName = g_strdup (buf + 14);
		else if (strncmp (buf, "# ROOTNAME ", 11) == 0)
			info->rootName = g_strdup (buf + 11);
		else if (strncmp (buf, "# SOFTWARE-VERSION ", 19) == 0)
			info->softwareVersion = g_strdup (buf + 19);
		else if (strncmp (buf, "# SUMMARY ", 10) == 0)
			info->summary = g_strdup (buf + 10);
		else if (strncmp (buf, "# PACKAGER ", 11) == 0)
			info->packager = g_strdup (buf + 11);
		else if (strncmp (buf, "# MAINTAINER ", 13) == 0)
			info->maintainer = g_strdup (buf + 13);
		else if (strncmp (buf, "skipLines=", 10) == 0)
			info->skipLines = (guint) atoi (strchr (buf, '=') + 1);
		else if (strncmp (buf, "MD5=", 4) == 0)
			info->md5sum = strchr (buf, '=') + 1;
	}

	fclose (f);

	/* Is this an Autopackage or just a shell script? */
	if (!info->skipLines || !info->rootName)
	{
		package_info_free (info);
		return NULL;
	}

	return info;
}


void
package_info_free (PackageInfo *info)
{
	g_return_if_fail (info != NULL);

	g_free (info);
}

#endif /* _PACKAGE_C_ */
